@@ -33,6 +33,9 @@ class CloverlyResource:
     def __init__(self, **kwargs: iter):
         # Initializes all passed in attributes as instance attributes
         for attr in kwargs:
+            if attr[0] == '_':
+                self.__setattr__(attr[1:], kwargs[attr])
+                continue
             self.__setattr__(attr, kwargs[attr])
 
     @classmethod
